#region File Description
//-----------------------------------------------------------------------------
// Settings.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.IO;
using System.Xml.Serialization;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
#endregion

namespace Snowflakes
{
    /// <summary>
    /// The Setting class handles loading and saving of global application settings.
    /// The normal .Net classes (System.Configuration) for doing this are not available
    /// on the Xbox 360.
    /// </summary>
    public class Settings
    {
        #region General App Settings

        /// <summary>
        /// The path to look for all media in
        /// </summary>
        public string MediaPath = @"Content\";

        /// <summary>
        /// The name of the window when running in windowed mode
        /// </summary>
        public string WindowTitle = "Snowflakes";

        #endregion

        #region SnowflakeColors

        /// <summary>
        /// Default snowflake colors to use
        /// </summary>
        public Color[] SnowflakeColors = new Color[] { new Color(255, 255, 255), //white
                                                    new Color(150, 210, 240),//blue
                                                    new Color(250, 240, 60),//yellow
                                                    new Color(121, 60, 150) //purple
                                                    };

        //monochrome
        //public Color[] SnowflakeColors = new Color[] { new Color(255, 255, 255), 
        //                                            new Color(205, 205, 205), 
        //                                            new Color(155, 155, 155), 
        //                                            new Color(105, 105, 105), 
        //                                            new Color(55, 55, 55) };
        //
        #endregion

        #region SnowflakeShapes

        /// <summary>
        /// Default snowflake shapes to use
        /// </summary>
        public string[] SnowflakeShapes = new string[] { "snowflake1",
                                                      "snowflake2",
                                                      "snowflake3",
                                                      "snowflake4",
                                                      "snowflake5",
                                                      "snowflake6",
                                                      "snowflake7",                                                                                                        
                                                      "snowflake8" };
        #endregion

        #region Load/Save code

        /// <summary>
        /// Saves the current settings
        /// </summary>
        /// <param name="filename">The filename to save to</param>
        public void Save(string filename)
        {
            Stream stream = File.Create(filename);

            XmlSerializer serializer = new XmlSerializer(typeof(Settings));
            serializer.Serialize(stream, this);
            stream.Close();
        }

        /// <summary>
        /// Loads settings from a file
        /// </summary>
        /// <param name="filename">The filename to load</param>
        public static Settings Load(string filename)
        {
            Stream stream = File.OpenRead(filename);
            XmlSerializer serializer = new XmlSerializer(typeof(Settings));
            return (Settings)serializer.Deserialize(stream);
        }

        #endregion
    }
}
