#region File Description
//-----------------------------------------------------------------------------
// TitleScreen.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
#endregion

namespace Snowflakes
{
    /// <summary>
    /// Title screen is the initial screen for Snowflakes. Allows you to select 2d or 3d 
    /// and displays the high scores
    /// </summary>
    public class TitleScreen : Screen
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TitleScreen"/> class.
        /// </summary>
        /// <param name="game">The game object to use</param>
        /// <param name="backgroundImage">The background image to use when this is 
        /// visible</param>
        /// <param name="backgroundMusic">The background music to play when this is 
        /// visible</param>
        public TitleScreen(Game game, string backgroundImage)
            : base(game, backgroundImage)
        {
        }

        /// <summary>
        /// Checks for game start button presses
        /// </summary>
        /// 
        public override void Update(GameTime gameTime)
        {
            base.Update(gameTime);

            GameState returnValue = GameState.None;

            //Transition to next state if those properties are set
            if (InputHelper.GamePads[PlayerIndex.One].APressed)
            {
                //Sound.Play(SoundEntry.Menu2DStart);
                returnValue = GameState.Play2D;
            }

            SnowflakesGame.NextGameState = returnValue;
        }

        /// <summary>
        /// Draws the high scores
        /// </summary>
        /// 
        public override void Draw(GameTime gameTime)
        {
            base.Draw(gameTime);

            //If the guide is visible - then there are no high scores yet and the array
            //will be null
            if (SnowflakesGame.HighScores != null)
            {
                SpriteBatch.Begin(SpriteBlendMode.AlphaBlend);

                //Draw the high scores
                for (int i = 0; i < 5; i++)
                {
                    if (SnowflakesGame.HighScores[i] != 0)
                    {
                        Snowflake sideSnowflake = new Snowflake("set shape", i);
                        sideSnowflake.Position = new Vector2(110, 140 + i * 50);
                        sideSnowflake.Draw(SpriteBatch);
                        Font.Draw(SpriteBatch, FontStyle.Large, 170, 120 + i * 50,
                                  SnowflakesGame.HighScores[i]);
                        sideSnowflake.Position = new Vector2(300, 140 + i * 50);
                        sideSnowflake.Draw(SpriteBatch);
                    }
                }

                SpriteBatch.End();
            }
        }
    }
}
